@@ -5,6 +5,7 @@ import os
 from functools import lru_cache
 from typing import Any, Callable, Dict, List, Union
 
+import sentencepiece as _sentencepiece
 import pytorch_lightning as pl
 from datasets import DatasetDict
 from loguru import logger
@@ -17,6 +18,9 @@ from transformers import (
 )
 from transformers.tokenization_utils_base import BatchEncoding
 
+# Sentencepiece has to be loaded before lightning
+_sentencepiece
+
 
 class LMDataset(Dataset):
     """LM dataset class."""
